CMCaseReader

Trait CMCaseReader 

pub trait CMCaseReader {
    // Required method
    fn read_case(path: &Path) -> Result<CMCase, DataError>;
}
A trait for reading a CMCase from a specified path.

Implement this trait for types that are capable of reading a case configuration from disk or another storage medium.

Required Methods

fn read_case(path: &Path) -> Result<CMCase, DataError>

Reads a CMCase from the given path.

Arguments
  • path - A reference to the Path from which to read the case configuration.
Returns

Returns a Result with a CMCase on success or a DataError on failure.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors