CMCaseWriter

Trait CMCaseWriter 

pub trait CMCaseWriter {
    // Required method
    fn write_case(case: CMCase, path: &Path) -> Result<(), DataError>;
}
A trait for writing a CMCase to a specified path.

Implement this trait for types that are capable of writing a case configuration to disk or another storage medium.

Required Methods

fn write_case(case: CMCase, path: &Path) -> Result<(), DataError>

Writes a CMCase to the given path.

Arguments
  • case - The CMCase instance to write.
  • path - A reference to the Path where the case configuration should be written.
Returns

Returns a Result indicating success or a DataError on failure.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors