pub trait CMCaseWriter {
// Required method
fn write_case(case: CMCase, path: &Path) -> Result<(), DataError>;
}Expand description
A trait for writing a CMCase to a specified path.
Implement this trait for types that are capable of writing a case configuration to disk or another storage medium.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.